@@ -18,7 +18,12 @@ program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
 import gi
-gi.require_version('Budgie', '1.0')
+gi.require_version('Libxfce4windowing', '0.0')
+from gi.repository import Libxfce4windowing
+if Libxfce4windowing.windowing_get() == Libxfce4windowing.Windowing.WAYLAND:
+    gi.require_version('Budgie', '3.0')
+else:
+    gi.require_version('Budgie', '1.0')
 gi.require_version('Gtk', '3.0')
 from gi.repository import Budgie, GObject, GdkPixbuf, Gtk, Gio, GLib
 from threading import Thread
